src/hg/hgTables/hgTables.c 1.178

1.178 2009/03/17 18:10:47 fanhsu
Added GSID servers to exclude for general Table Browser functions.
Index: src/hg/hgTables/hgTables.c
===================================================================
RCS file: /projects/compbio/cvsroot/kent/src/hg/hgTables/hgTables.c,v
retrieving revision 1.177
retrieving revision 1.178
diff -b -B -U 4 -r1.177 -r1.178
--- src/hg/hgTables/hgTables.c	17 Mar 2009 17:24:51 -0000	1.177
+++ src/hg/hgTables/hgTables.c	17 Mar 2009 18:10:47 -0000	1.178
@@ -1567,13 +1567,15 @@
  * By default head to the main page. */
 {
 struct hashEl *varList;
 
-/* only allows view table schema function for CGB servers for the time being */
-if (hIsCgbServer())
+/* only allows view table schema function for CGB or GSID servers for the time being */
+if (hIsCgbServer() || hIsGsidServer())
     {
     if (cartVarExists(cart, hgtaDoSchema))
+	{    
     	doSchema(conn);
+	}
     else
 	{
 	errAbort("Sorry, currently only the \"View Table Schema\" function of the Table Browser is available on this server.");
 	}